Connection Management Client
Author: BBC RD
Description: NMOS Connection Management User Interface

# NMOS Connection Management

API Root

## Senders

Master Enable

#####

### Staged Transport Parameters

Receiver UUID
Leg
Source IP
Destination IP
Source Port
Destination Port
RTP Enabled
FEC Enabled
FEC Destination IP
FEC Type
FEC Mode
FEC Block Width
FEC Block Height
FEC 1D Destination Port
FEC 1D Source Port
FEC 2D Destination Port
FEC 2D Source Port
RTCP Destination IP
RTCP Source Port
RTCP Destination Port
RTCP Enabled

Sender updated successfully

#####

### Activation

Seconds
Nanoseconds
Seconds
Nanoseconds

Activation successful

#####

### Active Transport File

Click here to get current transport file for this sender.

#####

### Active Transport Parameters

## Receivers

Master Enable

#####

### Staged Transport Parameters

Sender UUID
Leg
Source IP
Interface IP
Multicast Group IP
Source Port
Destination Port
RTP Enabled
FEC Enabled
FEC Destination IP
FEC Mode
FEC Block Width
FEC Block Height
FEC 1D Destination Port
FEC 1D Source Port
FEC 2D Destination Port
FEC 2D Source Port
RTCP Destination IP
RTCP Source Port
RTCP Destination Port
RTCP Enabled

Receiver updated successfully

#####

### Staged Transport File

Transport File Type
Data
Sender ID

Receiver transport file updated successfully

#####

### Activation

Seconds
Nanoseconds
Seconds
Nanoseconds

Activation successful

#####

### Active Transport Parameters